window.Gleam.initSearch([{"doc":"gleam_http","title":"gleam_http","content":"# Gleam HTTP\n\nTypes and functions for HTTP clients and servers!\n\n## HTTP Service Example\n\n```gleam\nimport gleam/http/elli\nimport gleam/http/response.{type Response}\nimport gleam/http/request.{type Request}\nimport gleam/bytes_tree.{type BytesTree}\n\n// Define a HTTP service\n//\npub fn my_service(_request: Request(t)) -&gt; Response(BytesTree) {\n  let body = bytes_tree.from_string(&quot;Hello, world!&quot;)\n\n  response.new(200)\n  |&gt; response.prepend_header(&quot;made-with&quot;, &quot;Gleam&quot;)\n  |&gt; response.set_body(body)\n}\n\n// Start it on port 3000 using the Elli web server\n//\npub fn main() {\n  elli.become(my_service, on_port: 3000)\n}\n```\n\n## Server adapters\n\nIn the example above the Elli Erlang web server is used to run the Gleam HTTP\nservice. Here&#39;s a full list of the server adapters available, sorted\nalphabetically.\n\n| Adapter                        | About                                                         |\n| ---                            | ---                                                           |\n| [Mist][mist]                   | [Mist][mist] is a high performance pure Gleam HTTP 1.1 server |\n| [cgi][cgi]                     | [cgi][cgi] is a adapter for the Common Gateway Interface. |\n| [gleam_cowboy][cowboy-adapter] | [Cowboy][cowboy] is an Erlang HTTP2 &amp; HTTP1.1 web server      |\n| [gleam_elli][elli-adapter]     | [Elli][elli] is an Erlang HTTP1.1 web server                  |\n| [gleam_plug][plug-adapter]     | [Plug][plug] is an Elixir web application interface           |\n\n[cgi]: https://github.com/lpil/cgi\n[cowboy-adapter]: https://github.com/gleam-lang/cowboy\n[cowboy]:https://github.com/ninenines/cowboy\n[elli-adapter]: https://github.com/gleam-lang/elli\n[elli]:https://github.com/elli-lib/elli\n[mist]: https://github.com/rawhat/mist\n[plug-adapter]: https://github.com/gleam-lang/plug\n[plug]:https://github.com/elixir-plug/plug\n\n## Client adapters\n\nClient adapters are used to send HTTP requests to services over the network.\nHere&#39;s a full list of the client adapters available, sorted alphabetically.\n\n| Adapter                          | About                                                    |\n| ---                              | ---                                                      |\n| [gleam_fetch][fetch-adapter]     | [fetch][fetch] is a HTTP client included with JavaScript |\n| [gleam_hackney][hackney-adapter] | [Hackney][hackney] is a simple HTTP client for Erlang    |\n| [gleam_httpc][httpc-adapter]     | [httpc][httpc] is a HTTP client included with Erlang     |\n\n[hackney]: https://github.com/benoitc/hackney\n[hackney-adapter]: https://github.com/gleam-lang/hackney\n[httpc]: https://erlang.org/doc/man/httpc.html\n[httpc-adapter]: https://github.com/gleam-lang/httpc\n[fetch]: https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API\n[fetch-adapter]: https://github.com/gleam-lang/fetch\n","url":"index.html"},{"doc":"gleam/http","title":"ContentDisposition","content":"pub type ContentDisposition {\n  ContentDisposition(String, parameters: List(#(String, String)))\n}\n\nContentDisposition(String, parameters: List(#(String, String)))\n\n\nSynonyms:\ngleam/http.ContentDisposition\ngleam/http ContentDisposition","url":"gleam/http.html#ContentDisposition"},{"doc":"gleam/http","title":"Header","content":"pub type Header =\n  #(String, String)\n A HTTP header is a key-value pair. Header keys must be all lowercase\n characters.\n\nSynonyms:\ngleam/http.Header\ngleam/http Header","url":"gleam/http.html#Header"},{"doc":"gleam/http","title":"Method","content":"pub type Method {\n  Get\n  Post\n  Head\n  Put\n  Delete\n  Trace\n  Connect\n  Options\n  Patch\n  Other(String)\n}\n HTTP standard method as defined by [RFC 2616](https://tools.ietf.org/html/rfc2616),\n and PATCH which is defined by [RFC 5789](https://tools.ietf.org/html/rfc5789).\nGet\n\n\nPost\n\n\nHead\n\n\nPut\n\n\nDelete\n\n\nTrace\n\n\nConnect\n\n\nOptions\n\n\nPatch\n\n\nOther(String)\n Non-standard but valid HTTP methods.\n\nSynonyms:\ngleam/http.Method\ngleam/http Method","url":"gleam/http.html#Method"},{"doc":"gleam/http","title":"MultipartBody","content":"pub type MultipartBody {\n  MultipartBody(chunk: BitArray, done: Bool, remaining: BitArray)\n  MoreRequiredForBody(\n    chunk: BitArray,\n    continuation: fn(BitArray) -&gt; Result(MultipartBody, Nil),\n  )\n}\n\nMultipartBody(chunk: BitArray, done: Bool, remaining: BitArray)\n The body for the part has been fully parsed.\ndone\n&lt;p&gt;This is &lt;code&gt;True&lt;/code&gt; if this was the last part in the multipart message,\notherwise there are more parts to parse.&lt;/p&gt;\n\nremaining\n&lt;p&gt;The remaining content that has not yet been parsed. This will contain\nthe next part if &lt;code&gt;done&lt;/code&gt; is &lt;code&gt;False&lt;/code&gt;, otherwise it will contain the\nepilogue, if any.&lt;/p&gt;\n\nMoreRequiredForBody(\n  chunk: BitArray,\n  continuation: fn(BitArray) -&gt; Result(MultipartBody, Nil),\n)\n\ncontinuation\n&lt;p&gt;Call this function to continue parsing the body for this part.&lt;/p&gt;\n\nSynonyms:\ngleam/http.MultipartBody\ngleam/http MultipartBody","url":"gleam/http.html#MultipartBody"},{"doc":"gleam/http","title":"MultipartHeaders","content":"pub type MultipartHeaders {\n  MultipartHeaders(headers: List(Header), remaining: BitArray)\n  MoreRequiredForHeaders(\n    continuation: fn(BitArray) -&gt; Result(MultipartHeaders, Nil),\n  )\n}\n\nMultipartHeaders(headers: List(Header), remaining: BitArray)\n The headers for the part have been fully parsed.\n Header keys are all lowercase.\nremaining\n&lt;p&gt;The remaining content that has not yet been parsed. This will contain\nthe body for this part, if any, and can be parsed with the\n&lt;code&gt;parse_multipart_body&lt;/code&gt; function.&lt;/p&gt;\n\nMoreRequiredForHeaders(\n  continuation: fn(BitArray) -&gt; Result(MultipartHeaders, Nil),\n)\n More input is required to parse the headers for this part.\ncontinuation\n&lt;p&gt;Call this function to continue parsing the headers for this part.&lt;/p&gt;\n\nSynonyms:\ngleam/http.MultipartHeaders\ngleam/http MultipartHeaders","url":"gleam/http.html#MultipartHeaders"},{"doc":"gleam/http","title":"Scheme","content":"pub type Scheme {\n  Http\n  Https\n}\n The two URI schemes for HTTP\n\nHttp\n\n\nHttps\n\n\nSynonyms:\ngleam/http.Scheme\ngleam/http Scheme","url":"gleam/http.html#Scheme"},{"doc":"gleam/http","title":"method_to_string","content":"pub fn method_to_string(method: Method) -&gt; String\n\nSynonyms:\ngleam/http.method_to_string\ngleam/http method_to_string","url":"gleam/http.html#method_to_string"},{"doc":"gleam/http","title":"parse_content_disposition","content":"pub fn parse_content_disposition(\n  header: String,\n) -&gt; Result(ContentDisposition, Nil)\n\nSynonyms:\ngleam/http.parse_content_disposition\ngleam/http parse_content_disposition","url":"gleam/http.html#parse_content_disposition"},{"doc":"gleam/http","title":"parse_method","content":"pub fn parse_method(s: String) -&gt; Result(Method, Nil)\n\nSynonyms:\ngleam/http.parse_method\ngleam/http parse_method","url":"gleam/http.html#parse_method"},{"doc":"gleam/http","title":"parse_multipart_body","content":"pub fn parse_multipart_body(\n  data: BitArray,\n  boundary: String,\n) -&gt; Result(MultipartBody, Nil)\n Parse the body for part of a multipart message, as defined in RFC 2045. The\n body is everything until the next boundary. This function is generally to be\n called after calling `parse_multipart_headers` for a given part.\n\n This function will accept input of any size, it is up to the caller to limit\n it if needed.\n\n To enable streaming parsing of multipart messages, this function will return\n a continuation if there is not enough data to fully parse the body, along\n with the data that has been parsed so far. Further information is available\n in the documentation for `MultipartBody`.\n\nSynonyms:\ngleam/http.parse_multipart_body\ngleam/http parse_multipart_body","url":"gleam/http.html#parse_multipart_body"},{"doc":"gleam/http","title":"parse_multipart_headers","content":"pub fn parse_multipart_headers(\n  data: BitArray,\n  boundary: String,\n) -&gt; Result(MultipartHeaders, Nil)\n Parse the headers for part of a multipart message, as defined in RFC 2045.\n\n This function skips any preamble before the boundary. The preamble may be\n retrieved using `parse_multipart_body`.\n\n This function will accept input of any size, it is up to the caller to limit\n it if needed.\n\n To enable streaming parsing of multipart messages, this function will return\n a continuation if there is not enough data to fully parse the headers.\n Further information is available in the documentation for `MultipartBody`.\n\nSynonyms:\ngleam/http.parse_multipart_headers\ngleam/http parse_multipart_headers","url":"gleam/http.html#parse_multipart_headers"},{"doc":"gleam/http","title":"scheme_from_string","content":"pub fn scheme_from_string(scheme: String) -&gt; Result(Scheme, Nil)\n Parse a HTTP scheme from a string\n\n # Examples\n\n    &gt; scheme_from_string(&quot;http&quot;)\n    Ok(Http)\n\n    &gt; scheme_from_string(&quot;ftp&quot;)\n    Error(Nil)\n\nSynonyms:\ngleam/http.scheme_from_string\ngleam/http scheme_from_string","url":"gleam/http.html#scheme_from_string"},{"doc":"gleam/http","title":"scheme_to_string","content":"pub fn scheme_to_string(scheme: Scheme) -&gt; String\n Convert a scheme into a string.\n\n # Examples\n\n    &gt; scheme_to_string(Http)\n    &quot;http&quot;\n\n    &gt; scheme_to_string(Https)\n    &quot;https&quot;\n\nSynonyms:\ngleam/http.scheme_to_string\ngleam/http scheme_to_string","url":"gleam/http.html#scheme_to_string"},{"doc":"gleam/http","title":"gleam/http","content":" Functions for working with HTTP data structures in Gleam.\n\n This module makes it easy to create and modify Requests and Responses, data types.\n A general HTTP message type is defined that enables functions to work on both requests and responses.\n\n This module does not implement a HTTP client or HTTP server, but it can be used as a base for them.","url":"gleam/http.html"},{"doc":"gleam/http/cookie","title":"Attributes","content":"pub type Attributes {\n  Attributes(\n    max_age: Option(Int),\n    domain: Option(String),\n    path: Option(String),\n    secure: Bool,\n    http_only: Bool,\n    same_site: Option(SameSitePolicy),\n  )\n}\n Attributes of a cookie when sent to a client in the `set-cookie` header.\nAttributes(\n  max_age: Option(Int),\n  domain: Option(String),\n  path: Option(String),\n  secure: Bool,\n  http_only: Bool,\n  same_site: Option(SameSitePolicy),\n)\n\n\nSynonyms:\ngleam/http/cookie.Attributes\ngleam/http/cookie Attributes","url":"gleam/http/cookie.html#Attributes"},{"doc":"gleam/http/cookie","title":"SameSitePolicy","content":"pub type SameSitePolicy {\n  Lax\n  Strict\n  None\n}\n Policy options for the SameSite cookie attribute\n\n https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie/SameSite\nLax\n\n\nStrict\n\n\nNone\n\n\nSynonyms:\ngleam/http/cookie.SameSitePolicy\ngleam/http/cookie SameSitePolicy","url":"gleam/http/cookie.html#SameSitePolicy"},{"doc":"gleam/http/cookie","title":"defaults","content":"pub fn defaults(scheme: Scheme) -&gt; Attributes\n Helper to create sensible default attributes for a set cookie.\n\n https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie#Attributes\nSynonyms:\ngleam/http/cookie.defaults\ngleam/http/cookie defaults","url":"gleam/http/cookie.html#defaults"},{"doc":"gleam/http/cookie","title":"parse","content":"pub fn parse(cookie_string: String) -&gt; List(#(String, String))\n Parse a list of cookies from a header string. Any malformed cookies will be\n discarded.\n\nSynonyms:\ngleam/http/cookie.parse\ngleam/http/cookie parse","url":"gleam/http/cookie.html#parse"},{"doc":"gleam/http/cookie","title":"set_header","content":"pub fn set_header(\n  name: String,\n  value: String,\n  attributes: Attributes,\n) -&gt; String\n\nSynonyms:\ngleam/http/cookie.set_header\ngleam/http/cookie set_header","url":"gleam/http/cookie.html#set_header"},{"doc":"gleam/http/cookie","title":"gleam/http/cookie","content":"","url":"gleam/http/cookie.html"},{"doc":"gleam/http/request","title":"Request","content":"pub type Request(body) {\n  Request(\n    method: Method,\n    headers: List(Header),\n    body: body,\n    scheme: Scheme,\n    host: String,\n    port: Option(Int),\n    path: String,\n    query: Option(String),\n  )\n}\n A HTTP request.\n\n The body of the request is parameterised. The HTTP server or client you are\n using will have a particular set of types it supports for the body.\n \nRequest(\n  method: Method,\n  headers: List(Header),\n  body: body,\n  scheme: Scheme,\n  host: String,\n  port: Option(Int),\n  path: String,\n  query: Option(String),\n)\n\nheaders\n&lt;p&gt;The request headers. The keys must always be lowercase.&lt;/p&gt;\n\nSynonyms:\ngleam/http/request.Request\ngleam/http/request Request","url":"gleam/http/request.html#Request"},{"doc":"gleam/http/request","title":"from_uri","content":"pub fn from_uri(uri: Uri) -&gt; Result(Request(String), Nil)\n Construct a request from a URI.\n\nSynonyms:\ngleam/http/request.from_uri\ngleam/http/request from_uri","url":"gleam/http/request.html#from_uri"},{"doc":"gleam/http/request","title":"get_cookies","content":"pub fn get_cookies(req: Request(a)) -&gt; List(#(String, String))\n Fetch the cookies sent in a request.\n\n Note badly formed cookie pairs will be ignored.\n RFC6265 specifies that invalid cookie names/attributes should be ignored.\nSynonyms:\ngleam/http/request.get_cookies\ngleam/http/request get_cookies","url":"gleam/http/request.html#get_cookies"},{"doc":"gleam/http/request","title":"get_header","content":"pub fn get_header(\n  request: Request(a),\n  key: String,\n) -&gt; Result(String, Nil)\n Get the value for a given header.\n\n If the request does not have that header then `Error(Nil)` is returned.\n\n Header keys are always lowercase in `gleam_http`. To use any uppercase\n letter is invalid.\n\nSynonyms:\ngleam/http/request.get_header\ngleam/http/request get_header","url":"gleam/http/request.html#get_header"},{"doc":"gleam/http/request","title":"get_query","content":"pub fn get_query(\n  request: Request(a),\n) -&gt; Result(List(#(String, String)), Nil)\n Decode the query of a request.\nSynonyms:\ngleam/http/request.get_query\ngleam/http/request get_query","url":"gleam/http/request.html#get_query"},{"doc":"gleam/http/request","title":"map","content":"pub fn map(\n  request: Request(a),\n  transform: fn(a) -&gt; b,\n) -&gt; Request(b)\n Update the body of a request using a given function.\n\nSynonyms:\ngleam/http/request.map\ngleam/http/request map","url":"gleam/http/request.html#map"},{"doc":"gleam/http/request","title":"new","content":"pub fn new() -&gt; Request(String)\n A request with commonly used default values. This request can be used as\n an initial value and then update to create the desired request.\n\nSynonyms:\ngleam/http/request.new\ngleam/http/request new","url":"gleam/http/request.html#new"},{"doc":"gleam/http/request","title":"path_segments","content":"pub fn path_segments(request: Request(a)) -&gt; List(String)\n Return the non-empty segments of a request path.\n\n # Examples\n\n \n &gt; new()\n &gt; |&gt; set_path(&quot;/one/two/three&quot;)\n &gt; |&gt; path_segments\n [&quot;one&quot;, &quot;two&quot;, &quot;three&quot;]\n \n\nSynonyms:\ngleam/http/request.path_segments\ngleam/http/request path_segments","url":"gleam/http/request.html#path_segments"},{"doc":"gleam/http/request","title":"prepend_header","content":"pub fn prepend_header(\n  request: Request(a),\n  key: String,\n  value: String,\n) -&gt; Request(a)\n Prepend the header with the given value under the given header key.\n\n Similar to `set_header` except if the header already exists it prepends\n another header with the same key.\n\n Header keys are always lowercase in `gleam_http`. To use any uppercase\n letter is invalid.\n\nSynonyms:\ngleam/http/request.prepend_header\ngleam/http/request prepend_header","url":"gleam/http/request.html#prepend_header"},{"doc":"gleam/http/request","title":"remove_cookie","content":"pub fn remove_cookie(req: Request(a), name: String) -&gt; Request(a)\n Remove a cookie from a request\n\n Remove a cookie from the request. If no cookie is found return the request unchanged.\n This will not remove the cookie from the client.\nSynonyms:\ngleam/http/request.remove_cookie\ngleam/http/request remove_cookie","url":"gleam/http/request.html#remove_cookie"},{"doc":"gleam/http/request","title":"set_body","content":"pub fn set_body(req: Request(a), body: b) -&gt; Request(b)\n Set the body of the request, overwriting any existing body.\n\nSynonyms:\ngleam/http/request.set_body\ngleam/http/request set_body","url":"gleam/http/request.html#set_body"},{"doc":"gleam/http/request","title":"set_cookie","content":"pub fn set_cookie(\n  req: Request(a),\n  name: String,\n  value: String,\n) -&gt; Request(a)\n Send a cookie with a request\n\n Multiple cookies are added to the same cookie header.\nSynonyms:\ngleam/http/request.set_cookie\ngleam/http/request set_cookie","url":"gleam/http/request.html#set_cookie"},{"doc":"gleam/http/request","title":"set_header","content":"pub fn set_header(\n  request: Request(a),\n  key: String,\n  value: String,\n) -&gt; Request(a)\n Set the header with the given value under the given header key.\n\n If already present, it is replaced.\n\n Header keys are always lowercase in `gleam_http`. To use any uppercase\n letter is invalid.\n\nSynonyms:\ngleam/http/request.set_header\ngleam/http/request set_header","url":"gleam/http/request.html#set_header"},{"doc":"gleam/http/request","title":"set_host","content":"pub fn set_host(req: Request(a), host: String) -&gt; Request(a)\n Set the host of the request.\n\nSynonyms:\ngleam/http/request.set_host\ngleam/http/request set_host","url":"gleam/http/request.html#set_host"},{"doc":"gleam/http/request","title":"set_method","content":"pub fn set_method(req: Request(a), method: Method) -&gt; Request(a)\n Set the method of the request.\n\nSynonyms:\ngleam/http/request.set_method\ngleam/http/request set_method","url":"gleam/http/request.html#set_method"},{"doc":"gleam/http/request","title":"set_path","content":"pub fn set_path(req: Request(a), path: String) -&gt; Request(a)\n Set the path of the request.\n\nSynonyms:\ngleam/http/request.set_path\ngleam/http/request set_path","url":"gleam/http/request.html#set_path"},{"doc":"gleam/http/request","title":"set_port","content":"pub fn set_port(req: Request(a), port: Int) -&gt; Request(a)\n Set the port of the request.\n\nSynonyms:\ngleam/http/request.set_port\ngleam/http/request set_port","url":"gleam/http/request.html#set_port"},{"doc":"gleam/http/request","title":"set_query","content":"pub fn set_query(\n  req: Request(a),\n  query: List(#(String, String)),\n) -&gt; Request(a)\n Set the query of the request.\n Query params will be percent encoded before being added to the Request.\n\nSynonyms:\ngleam/http/request.set_query\ngleam/http/request set_query","url":"gleam/http/request.html#set_query"},{"doc":"gleam/http/request","title":"set_scheme","content":"pub fn set_scheme(req: Request(a), scheme: Scheme) -&gt; Request(a)\n Set the scheme (protocol) of the request.\n\nSynonyms:\ngleam/http/request.set_scheme\ngleam/http/request set_scheme","url":"gleam/http/request.html#set_scheme"},{"doc":"gleam/http/request","title":"to","content":"pub fn to(url: String) -&gt; Result(Request(String), Nil)\n Construct a request from a URL string\n\nSynonyms:\ngleam/http/request.to\ngleam/http/request to","url":"gleam/http/request.html#to"},{"doc":"gleam/http/request","title":"to_uri","content":"pub fn to_uri(request: Request(a)) -&gt; Uri\n Return the uri that a request was sent to.\n\nSynonyms:\ngleam/http/request.to_uri\ngleam/http/request to_uri","url":"gleam/http/request.html#to_uri"},{"doc":"gleam/http/request","title":"gleam/http/request","content":"","url":"gleam/http/request.html"},{"doc":"gleam/http/response","title":"Response","content":"pub type Response(body) {\n  Response(status: Int, headers: List(Header), body: body)\n}\n A HTTP response.\n\n The body of the request is parameterised. The HTTP server or client you are\n using will have a particular set of types it supports for the body.\n \nResponse(status: Int, headers: List(Header), body: body)\n\nheaders\n&lt;p&gt;The request headers. The keys must always be lowercase.&lt;/p&gt;\n\nSynonyms:\ngleam/http/response.Response\ngleam/http/response Response","url":"gleam/http/response.html#Response"},{"doc":"gleam/http/response","title":"expire_cookie","content":"pub fn expire_cookie(\n  response: Response(a),\n  name: String,\n  attributes: Attributes,\n) -&gt; Response(a)\n Expire a cookie value for a client\n\n Note: The attributes value should be the same as when the response cookie was set.\nSynonyms:\ngleam/http/response.expire_cookie\ngleam/http/response expire_cookie","url":"gleam/http/response.html#expire_cookie"},{"doc":"gleam/http/response","title":"get_cookies","content":"pub fn get_cookies(resp: Response(a)) -&gt; List(#(String, String))\n Fetch the cookies sent in a response. \n\n Badly formed cookies will be discarded.\n\nSynonyms:\ngleam/http/response.get_cookies\ngleam/http/response get_cookies","url":"gleam/http/response.html#get_cookies"},{"doc":"gleam/http/response","title":"get_header","content":"pub fn get_header(\n  response: Response(a),\n  key: String,\n) -&gt; Result(String, Nil)\n Get the value for a given header.\n\n If the response does not have that header then `Error(Nil)` is returned.\n\nSynonyms:\ngleam/http/response.get_header\ngleam/http/response get_header","url":"gleam/http/response.html#get_header"},{"doc":"gleam/http/response","title":"map","content":"pub fn map(\n  response: Response(a),\n  transform: fn(a) -&gt; b,\n) -&gt; Response(b)\n Update the body of a response using a given function.\n\nSynonyms:\ngleam/http/response.map\ngleam/http/response map","url":"gleam/http/response.html#map"},{"doc":"gleam/http/response","title":"new","content":"pub fn new(status: Int) -&gt; Response(String)\n Construct an empty Response.\n\n The body type of the returned response is `String` and could be set with a\n call to `set_body`.\n\nSynonyms:\ngleam/http/response.new\ngleam/http/response new","url":"gleam/http/response.html#new"},{"doc":"gleam/http/response","title":"prepend_header","content":"pub fn prepend_header(\n  response: Response(a),\n  key: String,\n  value: String,\n) -&gt; Response(a)\n Prepend the header with the given value under the given header key.\n\n Similar to `set_header` except if the header already exists it prepends\n another header with the same key.\n\n Header keys are always lowercase in `gleam_http`. To use any uppercase\n letter is invalid.\n\nSynonyms:\ngleam/http/response.prepend_header\ngleam/http/response prepend_header","url":"gleam/http/response.html#prepend_header"},{"doc":"gleam/http/response","title":"redirect","content":"pub fn redirect(uri: String) -&gt; Response(String)\n Create a response that redirects to the given uri.\n\nSynonyms:\ngleam/http/response.redirect\ngleam/http/response redirect","url":"gleam/http/response.html#redirect"},{"doc":"gleam/http/response","title":"set_body","content":"pub fn set_body(response: Response(a), body: b) -&gt; Response(b)\n Set the body of the response, overwriting any existing body.\n\nSynonyms:\ngleam/http/response.set_body\ngleam/http/response set_body","url":"gleam/http/response.html#set_body"},{"doc":"gleam/http/response","title":"set_cookie","content":"pub fn set_cookie(\n  response: Response(a),\n  name: String,\n  value: String,\n  attributes: Attributes,\n) -&gt; Response(a)\n Set a cookie value for a client\n\nSynonyms:\ngleam/http/response.set_cookie\ngleam/http/response set_cookie","url":"gleam/http/response.html#set_cookie"},{"doc":"gleam/http/response","title":"set_header","content":"pub fn set_header(\n  response: Response(a),\n  key: String,\n  value: String,\n) -&gt; Response(a)\n Set the header with the given value under the given header key.\n\n If the response already has that key, it is replaced.\n\n Header keys are always lowercase in `gleam_http`. To use any uppercase\n letter is invalid.\n\nSynonyms:\ngleam/http/response.set_header\ngleam/http/response set_header","url":"gleam/http/response.html#set_header"},{"doc":"gleam/http/response","title":"try_map","content":"pub fn try_map(\n  response: Response(a),\n  transform: fn(a) -&gt; Result(b, c),\n) -&gt; Result(Response(b), c)\n Update the body of a response using a given result returning function.\n\n If the given function returns an `Ok` value the body is set, if it returns\n an `Error` value then the error is returned.\n\nSynonyms:\ngleam/http/response.try_map\ngleam/http/response try_map","url":"gleam/http/response.html#try_map"},{"doc":"gleam/http/response","title":"gleam/http/response","content":"","url":"gleam/http/response.html"},{"doc":"gleam/http/service","title":"Middleware","content":"@deprecated(&quot;Use middleware packages such as Wisp or Glen instead&quot;)\npub type Middleware(\n  before_req,\n  before_resp,\n  after_req,\n  after_resp,\n) =\n  fn(fn(Request(before_req)) -&gt; Response(before_resp)) -&gt;\n    fn(Request(after_req)) -&gt; Response(after_resp)\n\n\nSynonyms:\ngleam/http/service.Middleware\ngleam/http/service Middleware","url":"gleam/http/service.html#Middleware"},{"doc":"gleam/http/service","title":"Service","content":"@deprecated(&quot;Use middleware packages such as Wisp or Glen instead&quot;)\npub type Service(in, out) =\n  fn(Request(in)) -&gt; Response(out)\n\n\nSynonyms:\ngleam/http/service.Service\ngleam/http/service Service","url":"gleam/http/service.html#Service"},{"doc":"gleam/http/service","title":"map_response_body","content":"pub fn map_response_body(\n  service: fn(a) -&gt; Response(b),\n  with mapper: fn(b) -&gt; c,\n) -&gt; fn(a) -&gt; Response(c)\n\nSynonyms:\ngleam/http/service.map_response_body\ngleam/http/service map_response_body","url":"gleam/http/service.html#map_response_body"},{"doc":"gleam/http/service","title":"method_override","content":"pub fn method_override(\n  service: fn(Request(a)) -&gt; b,\n) -&gt; fn(Request(a)) -&gt; b\n\nSynonyms:\ngleam/http/service.method_override\ngleam/http/service method_override","url":"gleam/http/service.html#method_override"},{"doc":"gleam/http/service","title":"prepend_response_header","content":"pub fn prepend_response_header(\n  service: fn(a) -&gt; Response(b),\n  key: String,\n  value: String,\n) -&gt; fn(a) -&gt; Response(b)\n\nSynonyms:\ngleam/http/service.prepend_response_header\ngleam/http/service prepend_response_header","url":"gleam/http/service.html#prepend_response_header"},{"doc":"gleam/http/service","title":"gleam/http/service","content":"","url":"gleam/http/service.html"}]);